@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-09-11'; # DATE
-our $VERSION = '1.29'; # VERSION
+our $DATE = '2015-09-15'; # DATE
+our $VERSION = '1.30'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -252,8 +252,17 @@ sub hook_format_result {
     require Perinci::Result::Format::Lite;
     my ($self, $r) = @_;
 
-    Perinci::Result::Format::Lite::format(
-        $r->{res}, $r->{format} // 'text', $r->{naked_res});
+    my $fmt = $r->{format} // 'text';
+
+    my $fres = Perinci::Result::Format::Lite::format(
+        $r->{res}, $fmt, $r->{naked_res});
+
+    # ux: prefix error message with program name
+    if ($fmt =~ /text/ && $r->{res}[0] =~ /\A[45]/ && defined($r->{res}[1])) {
+        $fres = "$self->{program_name}: $fres";
+    }
+
+    $fres;
 }
 
 sub hook_format_row {
@@ -440,7 +449,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.29 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-11.
+This document describes version 1.30 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-15.
 
 =head1 SYNOPSIS
 
